@@ -6,47 +6,50 @@ __all__ = ("domain",)
 
 # XXX doc this up better...
 
-from collections import defaultdict
 import copy
+import os
+import re
+import tempfile
+from collections import defaultdict
 from functools import partial
 from itertools import chain
 from multiprocessing import cpu_count
 from operator import itemgetter
-import os
-import re
-import tempfile
 
 from snakeoil import klass
 from snakeoil.bash import iter_read_bash, read_bash_dict
 from snakeoil.cli.exceptions import find_user_exception
 from snakeoil.data_source import local_source
-from snakeoil.mappings import ProtectedDict, ImmutableDict
 from snakeoil.log import suppress_logging
+from snakeoil.mappings import ImmutableDict, ProtectedDict
 from snakeoil.osutils import pjoin
 from snakeoil.process.spawn import spawn_get_output
-from snakeoil.sequences import split_negations, stable_unique, predicate_split
+from snakeoil.sequences import predicate_split, split_negations, stable_unique
 
-from pkgcore.binpkg import repository as binary_repo
-from pkgcore.cache.flat_hash import md5_cache
-from pkgcore.config import errors as config_errors
-from pkgcore.config.domain import Failure, domain as config_domain
-from pkgcore.config.hint import ConfigHint
-from pkgcore.ebuild import const, repository as ebuild_repo
-from pkgcore.ebuild.atom import atom as _atom
-from pkgcore.ebuild.misc import (
-    ChunkedDataDict, chunked_data, collapsed_restrict_to_data,
-    incremental_expansion, incremental_expansion_license,
-    non_incremental_collapsed_restrict_to_data, optimize_incrementals)
-from pkgcore.ebuild.portage_conf import PortageConfig
-from pkgcore.ebuild.repo_objs import RepoConfig, OverlayedLicenses
-from pkgcore.ebuild.triggers import GenerateTriggers
-from pkgcore.fs.livefs import iter_scan, sorted_scan
-from pkgcore.log import logger
-from pkgcore.repository import filtered, errors as repo_errors
-from pkgcore.repository.util import RepositoryGroup
-from pkgcore.restrictions import packages, values
-from pkgcore.restrictions.delegated import delegate
-from pkgcore.util.parserestrict import parse_match, ParseError
+from ..binpkg import repository as binary_repo
+from ..cache.flat_hash import md5_cache
+from ..config import errors as config_errors
+from ..config.domain import Failure
+from ..config.domain import domain as config_domain
+from ..config.hint import ConfigHint
+from ..fs.livefs import iter_scan, sorted_scan
+from ..log import logger
+from ..repository import errors as repo_errors
+from ..repository import filtered
+from ..repository.util import RepositoryGroup
+from ..restrictions import packages, values
+from ..restrictions.delegated import delegate
+from ..util.parserestrict import ParseError, parse_match
+from . import const
+from . import repository as ebuild_repo
+from .atom import atom as _atom
+from .misc import (ChunkedDataDict, chunked_data, collapsed_restrict_to_data,
+                   incremental_expansion, incremental_expansion_license,
+                   non_incremental_collapsed_restrict_to_data,
+                   optimize_incrementals)
+from .portage_conf import PortageConfig
+from .repo_objs import OverlayedLicenses, RepoConfig
+from .triggers import GenerateTriggers
 
 
 def package_masks(iterable):
@@ -259,22 +262,16 @@ class domain(config_domain):
             # skipped because negations are required for license filtering.
             if incremental not in settings or incremental in ("USE", "ACCEPT_LICENSE"):
                 continue
-            s = set()
-            incremental_expansion(
-                s, settings[incremental],
-                f'while expanding {incremental}')
-            settings[incremental] = tuple(s)
+            settings[incremental] = tuple(incremental_expansion(
+                settings[incremental],
+                msg_prefix=f'while expanding {incremental}'))
 
         if 'ACCEPT_KEYWORDS' not in settings:
             raise Failure("No ACCEPT_KEYWORDS setting detected from profile, "
                           "or user config")
-        s = set()
-        default_keywords = []
-        incremental_expansion(
-            s, settings['ACCEPT_KEYWORDS'],
-            'while expanding ACCEPT_KEYWORDS')
-        default_keywords.extend(s)
-        settings['ACCEPT_KEYWORDS'] = set(default_keywords)
+        settings['ACCEPT_KEYWORDS'] = incremental_expansion(
+            settings['ACCEPT_KEYWORDS'],
+            msg_prefix='while expanding ACCEPT_KEYWORDS')
 
         # pull trigger options from the env
         self._triggers = GenerateTriggers(self, settings)
@@ -655,12 +652,15 @@ class domain(config_domain):
         repo = None
         path = os.path.abspath(path)
         with suppress_logging():
-            while path != self.root:
+            while True:
                 try:
                     repo = self.add_repo(path, config=config, configure=configure)
                     break
                 except repo_errors.InvalidRepo:
-                    path = os.path.dirname(path)
+                    parent = os.path.dirname(path)
+                    if parent == path:
+                        break
+                    path = parent
         return repo
 
     def _configure_repo(self, repo):
@@ -753,18 +753,17 @@ class domain(config_domain):
         for r in self.__repos:
             try:
                 repo = r.instantiate()
+                if not repo.is_supported:
+                    logger.warning(
+                        f'skipping {r.name!r} repo: unsupported EAPI {str(repo.eapi)!r}')
+                    continue
+                repos.append(repo)
             except config_errors.InstantiationError as e:
                 # roll back the exception chain to a meaningful error message
                 exc = find_user_exception(e)
                 if exc is None:
                     exc = e
                 logger.warning(f'skipping {r.name!r} repo: {exc}')
-                continue
-            if not repo.is_supported:
-                logger.warning(
-                    f'skipping {r.name!r} repo: unsupported EAPI {str(repo.eapi)!r}')
-                continue
-            repos.append(repo)
         return RepositoryGroup(repos)
 
     @klass.jit_attr_named('_jit_repo_installed_repos_raw', uncached_val=None)
