@@ -4,31 +4,33 @@ package class for buildable ebuilds
 
 __all__ = ("base", "package", "package_factory")
 
+import os
 from functools import partial
 from itertools import chain
-import os
 from sys import intern
 
 from snakeoil import chksum, data_source, fileutils, klass
 from snakeoil.demandload import demand_compile_regexp
+from snakeoil.mappings import OrderedFrozenSet
 
-from pkgcore import fetch
-from pkgcore.cache import errors as cache_errors
-from pkgcore.ebuild import conditionals, processor, errors as ebuild_errors
-from pkgcore.ebuild.atom import atom
-from pkgcore.ebuild.eapi import get_eapi
-from pkgcore.ebuild.misc import sort_keywords
-from pkgcore.log import logger
-from pkgcore.package import errors as metadata_errors, metadata
-from pkgcore.package.base import DynamicGetattrSetter
-from pkgcore.restrictions import boolean, values
-
+from .. import fetch
+from ..cache import errors as cache_errors
+from ..log import logger
+from ..package import errors as metadata_errors
+from ..package import metadata
+from ..package.base import DynamicGetattrSetter
+from ..restrictions import boolean, values
+from . import conditionals
+from . import errors as ebuild_errors
+from . import processor
+from .atom import atom
+from .eapi import get_eapi
+from .misc import sort_keywords
 
 demand_compile_regexp(
     '_EAPI_regex', r"^EAPI=(['\"]?)(?P<EAPI>[A-Za-z0-9+_.-]*)\1[\t ]*(?:#.*)?")
 demand_compile_regexp(
     '_EAPI_str_regex', r"^EAPI=(['\"]?)(?P<EAPI>.*)\1")
-demand_compile_regexp('_parse_inherit_regex', r'^\s*inherit\s(?P<eclasses>.*?)(#.*)?$')
 
 
 class base(metadata.package):
@@ -83,7 +85,7 @@ class base(metadata.package):
 
     @DynamicGetattrSetter.register
     def fullslot(self):
-        slot = self.data.pop('SLOT', None)
+        slot = self.data.get('SLOT', None)
         if not slot:
             raise metadata_errors.MetadataException(
                 self, 'slot', 'SLOT cannot be unset or empty')
@@ -226,11 +228,8 @@ class base(metadata.package):
         for line in i:
             if line[0:1] in ('', '#'):
                 continue
-            eapi_str = _EAPI_str_regex.match(line)
-            if eapi_str is not None:
-                eapi_str = eapi_str.group('EAPI')
-                if eapi_str:
-                    eapi = _EAPI_regex.match(line).group('EAPI')
+            if (mo := _EAPI_str_regex.match(line)) and (eapi_str := mo.group('EAPI')):
+                eapi = _EAPI_regex.match(line).group('EAPI')
             break
         try:
             return get_eapi(eapi)
@@ -274,27 +273,13 @@ class base(metadata.package):
 
     @DynamicGetattrSetter.register
     def inherited(self):
-        return tuple(sorted(self.data.get('_eclasses_', {})))
+        """Ordered set of all inherited eclasses."""
+        return OrderedFrozenSet(self.data.get("_eclasses_", ()))
 
     @DynamicGetattrSetter.register
     def inherit(self):
-        """Return the tuple of directly inherited eclasses for an ebuild."""
-        if self.ebuild.path:
-            # Use readlines directly since it does whitespace stripping
-            # for us, far faster than native python can.
-            i = fileutils.readlines_utf8(self.ebuild.path)
-        else:
-            i = (x.strip() for x in self.ebuild.text_fileobj())
-
-        # get all inherit line matches in the ebuild file
-        matches = filter(None, map(_parse_inherit_regex.match, i))
-        # and return direct inherits in the order they're seen
-        eclasses = []
-        for eclass in chain.from_iterable(m.group('eclasses').split() for m in matches):
-            # verify eclass is in inherited set to avoid conditional inherits
-            if eclass in self.inherited:
-                eclasses.append(eclass)
-        return tuple(eclasses)
+        """Ordered set of directly inherited eclasses."""
+        return OrderedFrozenSet(self.data.get("INHERIT", "").split())
 
     @staticmethod
     def _mk_required_use_node(data):
@@ -467,7 +452,6 @@ class package_factory(metadata.factory):
                 raise metadata_errors.MetadataException(
                     pkg, 'data', 'failed sourcing ebuild', e)
 
-        inherited = mydata.pop("INHERITED", None)
         # Rewrite defined_phases as needed, since we now know the EAPI.
         eapi = get_eapi(mydata.get('EAPI', '0'))
         if parsed_eapi != eapi:
@@ -486,9 +470,8 @@ class package_factory(metadata.factory):
             phases.discard(None)
             mydata["DEFINED_PHASES"] = ' '.join(sorted(phases))
 
-        if inherited:
-            mydata["_eclasses_"] = self._ecache.get_eclass_data(
-                inherited.split())
+        if inherited := mydata.pop("INHERITED", None):
+            mydata["_eclasses_"] = self._ecache.get_eclass_data(inherited.split())
         mydata['_chf_'] = chksum.LazilyHashedPath(pkg.path)
 
         for x in wipes:
@@ -508,12 +491,18 @@ class package_factory(metadata.factory):
         return mydata
 
     def new_package(self, *args):
-        inst = self._cached_instances.get(args)
+        if self._parent_repo.package_cache:
+            inst = self._cached_instances.get(args)
+        else:
+            # package caching is disabled
+            inst = None
+
         if inst is None:
             # key being cat/pkg
             mxml = self._parent_repo._get_shared_pkg_data(args[0], args[1])
             inst = self._cached_instances[args] = self.child_class(
                 mxml, self, *args)
+
         return inst
 
 
