@@ -16,11 +16,11 @@ from functools import partial
 from itertools import chain
 
 from snakeoil import mappings
-from snakeoil.klass import generic_equality, alias_method
+from snakeoil.klass import alias_method, generic_equality
 from snakeoil.sequences import iflatten_instance
 
-from pkgcore.ebuild import atom
-from pkgcore.restrictions import packages, restriction, boolean
+from ..restrictions import boolean, packages, restriction
+from . import atom
 
 restrict_payload = namedtuple("restrict_data", ["restrict", "data"])
 chunked_data = namedtuple("chunked_data", ("key", "neg", "pos"))
@@ -33,6 +33,7 @@ def sort_keywords(keywords):
         return parts[0], parts[2]
     return sorted(keywords, key=_sort_kwds)
 
+
 def optimize_incrementals(sequence):
     # roughly the algorithm walks sequences right->left,
     # identifying terminal points for incrementals; aka, -x x, 'x'
@@ -62,19 +63,10 @@ def incremental_chunked(orig, iterables):
         orig.update(cinst.pos)
 
 
-def render_incrementals(iterable, **kwds):
-    """helper function for simple incremental_expansion calls
+def incremental_expansion(iterable, orig=None, msg_prefix='', finalize=True):
+    if orig is None:
+        orig = set()
 
-    :param iterable: sequence of items to incrementally stack
-    :param kwargs: options to pass to incremental_expansion
-    :return: a set of the rendered results from incremental_expansion
-    """
-    s = set()
-    incremental_expansion(s, iterable, **kwds)
-    return s
-
-
-def native_incremental_expansion(orig, iterable, msg_prefix='', finalize=True):
     for token in iterable:
         if token[0] == '-':
             i = token[1:]
@@ -91,10 +83,7 @@ def native_incremental_expansion(orig, iterable, msg_prefix='', finalize=True):
             orig.discard("-" + token)
             orig.add(token)
 
-try:
-    from pkgcore.ebuild._misc import incremental_expansion
-except ImportError:
-    incremental_expansion = native_incremental_expansion
+    return orig
 
 
 def incremental_expansion_license(pkg, licenses, license_groups, iterable, msg_prefix=''):
@@ -214,9 +203,7 @@ class collapsed_restrict_to_data(metaclass=generic_equality):
                         f"or atom: data {data!r}")
 
         if always:
-            s = set()
-            incremental_expansion(s, always, finalize=kwds.get("finalize_defaults", True))
-            always = s
+            always = incremental_expansion(always, finalize=kwds.get("finalize_defaults", True))
         else:
             always = set()
         self.defaults = always
@@ -236,12 +223,12 @@ class collapsed_restrict_to_data(metaclass=generic_equality):
 
         if pre_defaults:
             s = set(pre_defaults)
-            incremental_expansion(s, self.defaults)
+            incremental_expansion(self.defaults, orig=s)
         else:
             s = set(self.defaults_finalized)
 
         if l:
-            incremental_expansion(s, iflatten_instance(l))
+            incremental_expansion(iflatten_instance(l), orig=s)
         return s
 
     def iter_pull_data(self, pkg, pre_defaults=()):
@@ -554,11 +541,9 @@ class PayloadDict(ChunkedDataDict):
         if items is None:
             items = self._global_settings
         s = set(pre_defaults)
-        incremental_expansion(
-            s,
-            chain.from_iterable(
-                item.data for item in items if item.restrict.match(pkg)))
-        return s
+        data = chain.from_iterable(
+            item.data for item in items if item.restrict.match(pkg))
+        return incremental_expansion(data, orig=s)
 
     pull_data = render_pkg
 
