@@ -3,36 +3,28 @@ __all__ = (
     "UserProfile",
 )
 
+import os
 from collections import defaultdict, namedtuple
 from functools import partial
 from itertools import chain
-import os
 
 from snakeoil import caching, klass
 from snakeoil.bash import iter_read_bash, read_bash_dict
-from snakeoil.containers import InvertedContains
 from snakeoil.data_source import local_source
 from snakeoil.fileutils import readlines_utf8
 from snakeoil.mappings import ImmutableDict
 from snakeoil.osutils import abspath, pjoin
 from snakeoil.sequences import split_negations, stable_unique
 
-from pkgcore.config import errors
-from pkgcore.config.hint import ConfigHint
-from pkgcore.ebuild import const, ebuild_src, misc, cpv, repo_objs, errors as ebuild_errors
-from pkgcore.ebuild.atom import atom
-from pkgcore.ebuild.eapi import get_eapi
-from pkgcore.fs.livefs import sorted_scan
-from pkgcore.log import logger
-
-
-def package_keywords_splitter(iterable):
-    for line, lineno, path in iterable:
-        v = line.split()
-        try:
-            yield atom(v[0]), tuple(v[1:]), line, lineno, path
-        except ebuild_errors.MalformedAtom as e:
-            logger.error(f'{path!r}, line {lineno}: parsing error: {e}')
+from ..config import errors
+from ..config.hint import ConfigHint
+from ..fs.livefs import sorted_scan
+from ..log import logger
+from . import const, cpv
+from . import errors as ebuild_errors
+from . import misc, repo_objs
+from .atom import atom
+from .eapi import EAPI, get_eapi
 
 
 class ProfileError(errors.ParsingError):
@@ -56,9 +48,16 @@ class NonexistentProfile(ProfileError):
 def _read_profile_files(files, allow_line_cont=False):
     """Read all the given data files."""
     for path in files:
+        # determine file path relative to the profiles dir
+        try:
+            relpath = path.split('/profiles/')[1]
+        except IndexError:
+            # profiles base path
+            relpath = os.path.basename(path)
+
         for lineno, line in iter_read_bash(
                 path, allow_line_cont=allow_line_cont, enum_line=True):
-            yield line, lineno, path
+            yield line, lineno, relpath
 
 
 def load_property(filename, *, read_func=_read_profile_files, fallback=(),
@@ -86,6 +85,7 @@ def load_property(filename, *, read_func=_read_profile_files, fallback=(),
             allow_recurse, allow_line_cont, parse_func, eapi_optional))
     return f
 
+
 def _load_and_invoke(func, filename, read_func, fallback, allow_recurse,
                      allow_line_cont, parse_func, eapi_optional, self):
     if eapi_optional is not None and not getattr(self.eapi.options, eapi_optional, None):
@@ -133,7 +133,7 @@ class ProfileNode(metaclass=caching.WeakInstMeta):
     _repo_map = None
 
     def __init__(self, path, pms_strict=True):
-        self.path = path
+        self.path = path.rstrip(os.path.sep)
         if not os.path.isdir(self.path):
             raise NonexistentProfile(self.path)
         self.pms_strict = pms_strict
@@ -149,7 +149,12 @@ class ProfileNode(metaclass=caching.WeakInstMeta):
 
     @klass.jit_attr
     def name(self):
-        return self.path.split('/profiles/')[-1]
+        """Relative path to the profile from the profiles directory."""
+        try:
+            return self.path.split('/profiles/')[1]
+        except IndexError:
+            # profiles base path
+            return ''
 
     @load_property("packages")
     def packages(self, data):
@@ -158,7 +163,7 @@ class ProfileNode(metaclass=caching.WeakInstMeta):
         profile_set = repo_config is not None and 'profile-set' in repo_config.profile_formats
         sys, neg_sys, pro, neg_pro = [], [], [], []
         neg_wildcard = False
-        for line, lineno, path in data:
+        for line, lineno, relpath in data:
             try:
                 if line[0] == '-':
                     if line == '-*':
@@ -168,22 +173,16 @@ class ProfileNode(metaclass=caching.WeakInstMeta):
                     elif profile_set:
                         neg_pro.append(self.eapi_atom(line[1:]))
                     else:
-                        logger.error(
-                            f'invalid line format, '
-                            f'{self.name}/packages, line {lineno}: {line!r}'
-                        )
+                        logger.error(f'{relpath!r}: invalid line format, line {lineno}: {line!r}')
                 else:
                     if line[0] == '*':
                         sys.append(self.eapi_atom(line[1:]))
                     elif profile_set:
                         pro.append(self.eapi_atom(line))
                     else:
-                        logger.error(
-                            f'invalid line format, '
-                            f'{self.name}/packages, line {lineno}: {line!r}'
-                        )
+                        logger.error(f'{relpath!r}: invalid line format, line {lineno}: {line!r}')
             except ebuild_errors.MalformedAtom as e:
-                logger.error(f'{self.name}/packages, line {lineno}: {e}')
+                logger.error(f'{relpath!r}, line {lineno}: parsing error: {e}')
         system = [tuple(neg_sys), tuple(sys)]
         profile = [tuple(neg_pro), tuple(pro)]
         if neg_wildcard:
@@ -196,7 +195,7 @@ class ProfileNode(metaclass=caching.WeakInstMeta):
         repo_config = self.repoconfig
         if repo_config is not None and 'portage-2' in repo_config.profile_formats:
             l = []
-            for line, lineno, path in data:
+            for line, lineno, relpath in data:
                 repo_id, separator, profile_path = line.partition(':')
                 if separator:
                     if repo_id:
@@ -211,7 +210,7 @@ class ProfileNode(metaclass=caching.WeakInstMeta):
                             else:
                                 logger.error(
                                     f'repo {repo_config.repo_id!r}: '
-                                    f"'{self.name}/parent' (line {lineno}), "
+                                    f"{relpath!r} (line {lineno}), "
                                     f'bad profile parent {line!r}: '
                                     f'unknown repo {repo_id!r}'
                                 )
@@ -221,7 +220,7 @@ class ProfileNode(metaclass=caching.WeakInstMeta):
                     l.append((abspath(pjoin(self.path, repo_id)), line, lineno))
             return tuple(l)
         return tuple((abspath(pjoin(self.path, line)), line, lineno)
-                     for line, lineno, path in data)
+                     for line, lineno, relpath in data)
 
     @klass.jit_attr
     def parents(self):
@@ -253,11 +252,11 @@ class ProfileNode(metaclass=caching.WeakInstMeta):
     def _parse_atom_negations(self, data):
         """Parse files containing optionally negated package atoms."""
         neg, pos = [], []
-        for line, lineno, path in data:
+        for line, lineno, relpath in data:
             if line[0] == '-':
                 line = line[1:]
                 if not line:
-                    logger.error(f"{path!r}, line {lineno}: '-' negation without an atom")
+                    logger.error(f"{relpath!r}, line {lineno}: '-' negation without an atom")
                     continue
                 l = neg
             else:
@@ -265,9 +264,18 @@ class ProfileNode(metaclass=caching.WeakInstMeta):
             try:
                 l.append(self.eapi_atom(line))
             except ebuild_errors.MalformedAtom as e:
-                logger.error(f'{path!r}, line {lineno}: parsing error: {e}')
+                logger.error(f'{relpath!r}, line {lineno}: parsing error: {e}')
         return tuple(neg), tuple(pos)
 
+    def _package_keywords_splitter(self, iterable):
+        """Parse package keywords files."""
+        for line, lineno, relpath in iterable:
+            v = line.split()
+            try:
+                yield (atom(v[0]), tuple(stable_unique(v[1:])))
+            except ebuild_errors.MalformedAtom as e:
+                logger.error(f'{relpath!r}, line {lineno}: parsing error: {e}')
+
     @load_property("package.mask", allow_recurse=True)
     def masks(self, data):
         return self._parse_atom_negations(data)
@@ -280,15 +288,13 @@ class ProfileNode(metaclass=caching.WeakInstMeta):
     def pkg_deprecated(self, data):
         return self._parse_atom_negations(data)
 
-    @load_property("package.keywords", allow_recurse=True,
-                   parse_func=package_keywords_splitter)
+    @load_property("package.keywords", allow_recurse=True)
     def keywords(self, data):
-        return tuple((x[0], tuple(stable_unique(x[1]))) for x in data)
+        return tuple(self._package_keywords_splitter(data))
 
-    @load_property("package.accept_keywords", allow_recurse=True,
-                   parse_func=package_keywords_splitter)
+    @load_property("package.accept_keywords", allow_recurse=True)
     def accept_keywords(self, data):
-        return tuple((x[0], tuple(stable_unique(x[1]))) for x in data)
+        return tuple(self._package_keywords_splitter(data))
 
     @load_property("package.use", allow_recurse=True)
     def pkg_use(self, data):
@@ -317,15 +323,15 @@ class ProfileNode(metaclass=caching.WeakInstMeta):
     def _parse_package_use(self, data):
         d = defaultdict(list)
         # split the data down ordered cat/pkg lines
-        for line, lineno, path in data:
+        for line, lineno, relpath in data:
             l = line.split()
             try:
                 a = self.eapi_atom(l[0])
             except ebuild_errors.MalformedAtom as e:
-                logger.error(e)
+                logger.error(f'{relpath!r}, line {lineno}: parsing error: {e}')
                 continue
             if len(l) == 1:
-                logger.error(f'{path!r}, line {lineno}: missing USE flag(s): {line!r}')
+                logger.error(f'{relpath!r}, line {lineno}: missing USE flag(s): {line!r}')
                 continue
             d[a.key].append(misc.chunked_data(a, *split_negations(l[1:])))
 
@@ -443,19 +449,30 @@ class ProfileNode(metaclass=caching.WeakInstMeta):
             return local_source(path)
         return None
 
-    @load_property('eapi', fallback=('0',))
+    @load_property('eapi', fallback='0')
     def eapi(self, data):
+        # handle fallback
+        if isinstance(data, str):
+            return get_eapi(data)
+
         try:
-            data = (x[0] for x in data)
-            data = (x.strip() for x in data)
-            data = [x for x in data if x]
-            if len(data) > 1:
-                logger.error(f'{self.name}/eapi, multiple lines detected')
-            return get_eapi(data[0])
-        except IndexError:
-            logger.error(f'{self.name}/eapi, empty file')
+            line, lineno, relpath = next(data)
+        except StopIteration:
+            relpath = pjoin(self.name, 'eapi')
+            logger.error(f'{relpath!r}: empty file')
             return get_eapi('0')
 
+        try:
+            next(data)
+            logger.error(f'{relpath!r}: multiple lines detected')
+        except StopIteration:
+            pass
+
+        eapi_str = line.strip()
+        if eapi_str not in EAPI.known_eapis:
+            logger.error(f'{relpath!r}: unknown EAPI {eapi_str!r}')
+        return get_eapi(eapi_str)
+
     eapi_atom = klass.alias_attr("eapi.atom_kls")
 
     @klass.jit_attr
@@ -599,9 +616,8 @@ class ProfileStack:
                 if incremental in const.incrementals_unfinalized:
                     d[incremental] = tuple(v)
                 else:
-                    v = misc.render_incrementals(
-                        v,
-                        msg_prefix=f"While expanding {incremental}, value {v!r}: ")
+                    v = misc.incremental_expansion(
+                        v, msg_prefix=f"While expanding {incremental}, value {v!r}: ")
                     if v:
                         d[incremental] = tuple(v)
         return ImmutableDict(d.items())
@@ -685,7 +701,7 @@ class ProfileStack:
     @klass.jit_attr
     def provides_repo(self):
         # delay importing to avoid circular imports
-        from pkgcore.ebuild.repository import ProvidesRepo
+        from .repository import ProvidesRepo
         return ProvidesRepo(pkgs=self._collapse_generic("pkg_provided"))
 
     @klass.jit_attr
