@@ -9,9 +9,9 @@ __all__ = ("AndRestriction", "OrRestriction")
 
 from itertools import islice
 
-from snakeoil.klass import generic_equality, cached_hash
+from snakeoil.klass import cached_hash, generic_equality
 
-from pkgcore.restrictions import restriction
+from . import restriction
 
 
 class base(restriction.base, metaclass=generic_equality):
