@@ -5,32 +5,35 @@ __all__ = (
     "perl_rebuild", "perl_rebuild_main", "env_update", "env_update_main",
 )
 
-from multiprocessing import cpu_count
+import argparse
+import logging
 import os
 import re
 import textwrap
 import time
+from multiprocessing import cpu_count
 
 from snakeoil.cli import arghparse
 from snakeoil.contexts import patch
 from snakeoil.fileutils import AtomicWriteFile
-from snakeoil.osutils import pjoin, listdir_dirs
+from snakeoil.osutils import listdir_dirs, pjoin
 from snakeoil.sequences import iter_stable_unique
 
-from pkgcore import const
-from pkgcore.cache.flat_hash import md5_cache
-from pkgcore.ebuild import triggers, repository as ebuild_repo
-from pkgcore.ebuild.cpv import CPV
-from pkgcore.exceptions import PkgcoreUserException
-from pkgcore.fs import contents, livefs
-from pkgcore.merge import triggers as merge_triggers
-from pkgcore.operations import observer as observer_mod, OperationError
-from pkgcore.package import mutated
-from pkgcore.package.errors import MetadataException
-from pkgcore.restrictions import packages
-from pkgcore.util import commandline
-from pkgcore.util.parserestrict import parse_match
-
+from ..cache.flat_hash import md5_cache
+from ..ebuild import repository as ebuild_repo
+from ..ebuild import triggers
+from ..ebuild.cpv import CPV
+from ..ebuild.eclass import EclassDoc
+from ..exceptions import PkgcoreUserException
+from ..fs import contents, livefs
+from ..merge import triggers as merge_triggers
+from ..operations import OperationError
+from ..operations import observer as observer_mod
+from ..package import mutated
+from ..package.errors import MetadataException
+from ..restrictions import packages
+from ..util import commandline
+from ..util.parserestrict import parse_match
 
 pkgcore_opts = commandline.ArgumentParser(domain=False, script=(__file__, __name__))
 argparser = commandline.ArgumentParser(
@@ -277,7 +280,7 @@ regen_opts.add_argument(
     "--force", action='store_true', default=False,
     help="force regeneration to occur regardless of staleness checks or repo settings")
 regen_opts.add_argument(
-    "--dir", dest='cache_dir',
+    "--dir", dest='cache_dir', type=arghparse.create_dir,
     help="use separate directory to store repository caches")
 regen_opts.add_argument(
     "--rsync", action='store_true', default=False,
@@ -297,7 +300,7 @@ def regen_main(options, out, err):
     for repo in iter_stable_unique(options.repos):
         if options.cache_dir is not None:
             # recreate new repo object with cache dir override
-            cache = (md5_cache(pjoin(options.cache_dir.strip(os.sep), repo.repo_id)),)
+            cache = (md5_cache(pjoin(options.cache_dir.rstrip(os.sep), repo.repo_id)),)
             repo = ebuild_repo.tree(
                 options.config, repo.config, cache=cache)
         if not repo.operations.supports("regen_cache"):
@@ -529,3 +532,92 @@ def digest_main(options, out, err):
         force=options.force)
 
     return int(any(failed))
+
+
+class EclassArgs(argparse.Action):
+    """Determine eclass arguments for `pmaint eclass`."""
+
+    def __call__(self, parser, namespace, values, option_string=None):
+        if values:
+            eclasses = []
+            for val in values:
+                path = os.path.realpath(val)
+                if os.path.isdir(path):
+                    eclasses.extend(os.listdir(path))
+                elif val.endswith('.eclass'):
+                    eclasses.append(path)
+                else:
+                    raise argparse.ArgumentError(self, f'invalid eclass: {val!r}')
+            eclasses = sorted(x for x in eclasses if x.endswith('.eclass'))
+        else:
+            eclass_dir = pjoin(namespace.repo.location, 'eclass')
+            try:
+                files = sorted(os.listdir(eclass_dir))
+            except FileNotFoundError:
+                files = []
+            eclasses = [pjoin(eclass_dir, x) for x in files if x.endswith('.eclass')]
+            if not eclasses:
+                parser.error(f'{namespace.repo.repo_id} repo: no eclasses found')
+
+        setattr(namespace, self.dest, eclasses)
+
+
+eclass = subparsers.add_parser(
+    "eclass", parents=shared_options_domain,
+    description="generate eclass docs")
+eclass.add_argument(
+    'eclasses', nargs='*', help="eclasses to target",
+    action=arghparse.Delayed, target=EclassArgs, priority=1001)
+eclass_opts = eclass.add_argument_group("subcommand options")
+eclass_opts.add_argument(
+    "--dir", dest='output_dir', type=arghparse.create_dir, help="output directory")
+eclass_opts.add_argument(
+    "-f", "--format", help="output format",
+    default='man', choices=('rst', 'man', 'html'))
+eclass_opts.add_argument(
+    "-r", "--repo", help="target repository",
+    action=commandline.StoreRepoObject, repo_type='ebuild-raw', allow_external_repos=True,
+    docs="""
+        Target repository to search for eclasses. If no repo is specified the default repo is used.
+    """)
+
+
+@eclass.bind_delayed_default(1000, 'repo')
+def _eclass_default_repo(namespace, attr):
+    """Use default repo if none is selected."""
+    repo = namespace.config.get_default('repo')
+    setattr(namespace, attr, repo)
+
+
+@eclass.bind_delayed_default(1000, 'output_dir')
+def _eclass_default_output_dir(namespace, attr):
+    """Use CWD as output dir if unset."""
+    setattr(namespace, attr, os.getcwd())
+
+
+@eclass.bind_main_func
+def _eclass_main(options, out, err):
+    # suppress all eclassdoc parsing warnings
+    logging.getLogger('pkgcore').setLevel(100)
+    failed = []
+
+    # determine output file extension
+    ext_map = {'man': '5'}
+    ext = ext_map.get(options.format, options.format)
+
+    for path in options.eclasses:
+        try:
+            with open(pjoin(options.output_dir, f'{os.path.basename(path)}.{ext}'), 'wt') as f:
+                obj = EclassDoc(path)
+                convert_func = getattr(obj, f'to_{options.format}')
+                f.write(convert_func())
+        except ValueError as e:
+            # skip eclasses lacking eclassdoc support
+            err.write(f'{eclass.prog}: skipping {path!r}: {e}')
+            err.flush()
+        except IOError as e:
+            err.write(f'{eclass.prog}: error: {path!r}: {e}')
+            err.flush()
+            failed.append(path)
+
+    return int(any(failed))
