@@ -1,6 +1,7 @@
-from pkgcore.package import metadata, base
 from snakeoil.test import TestCase
 
+from pkgcore.package import base, metadata
+
 
 def make_pkg_kls(attrs=(), callbacks={}):
 
